<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Groove_ZipSearch
 *
 * PHP version 4 or newer
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   Services
 * @package    Groove_ZipSearch
 * @author     Norifumi SUNAOKA
 * @copyright  2007 Norifumi SUNAOKA
 * @license    http://www.php.net/license/3_0.txt PHP License 3.0
 */

require_once 'PEAR.php';
require_once 'HTTP/Request.php';

/**
 * Groove_ZipSearch
 *
 * Interface for Groove::ZipSearch
 *
 * @category   Services
 * @package    Groove_ZipSearch
 * @author     Norifumi SUNAOKA
 * @copyright  2007 Norifumi SUNAOKA
 * @license    http://www.php.net/license/3_0.txt PHP License 3.0
 * @version    Release: 0.1.1
 */
class Services_Groove_ZipSearch
{
    var $_service_url = 'http://groovetechnology.co.jp/ZipSearchService/v1/zipsearch';
    
    function Services_Groove_ZipSearch()
    {
    }

    function search($zipcode, $word = '', $format = 'PHP', $callback = '', $ie = '', $oe = 'UTF-8')
    {
        $params = array(
            'zipcode'  => $zipcode,
            'word'     => $word,
            'format'   => $format,
            'callback' => $callback,
            'ie'       => $ie,
            'oe'       => $oe,
        );
        return $this->_fetch($params);
    }
    
    function _fetch($params)
    {
        $query = $this->_http_build_query($params);
        
        $http = new HTTP_Request();
        $request_url = $this->_service_url . '?' . $query;
        $http->setURL($request_url);
        $http->setMethod(HTTP_REQUEST_METHOD_GET);
        $response = $http->sendRequest();
        
        if (PEAR::isError($response)) {
            return PEAR::raiseError($response->getMessage());
        }
        
        $response_code = $http->getResponseCode();
        if ($response_code !== 200) {
            return PEAR::raiseError('HTTP-Error', $response_code);
        }

        $error_header = $http->getResponseHeader('X-GT-Error');
        if ($error_header !== false) {
            return PEAR::raiseError('X-GT-Error', $error_header);
        }
        
        return $http->getResponseBody();
    }
    
    function _http_build_query($array)
    {
        $result = array();
        foreach ((array)$array as $name => $value) {
            if (is_array($value)) {
                $result[] = $this->_http_build_query($value);
            } else {
                $result[] = urlencode($name) . '=' . urlencode($value);
            }
        }
        return implode('&', $result);
    }
}
?>
